Enum actix_http::body::BodySize
source · [−]pub enum BodySize {
None,
Sized(u64),
Stream,
}Expand description
Body size hint.
Variants
None
Implicitly empty body.
Will omit the Content-Length header. Used for responses to certain methods (e.g., HEAD) or
with particular status codes (e.g., 204 No Content). Consumers that read this as a body size
hint are allowed to make optimizations that skip reading or writing the payload.
Sized(u64)
Known size body.
Will write Content-Length: N header.
Stream
Unknown size body.
Will not write Content-Length header. Can be used with chunked Transfer-Encoding.
Implementations
Returns true if size hint indicates omitted or empty body.
Streams will return false because it cannot be known without reading the stream.
assert!(BodySize::None.is_eof());
assert!(BodySize::Sized(0).is_eof());
assert!(!BodySize::Sized(64).is_eof());
assert!(!BodySize::Stream.is_eof());Trait Implementations