Struct actix_http::body::SizedStream [−][src]
pub struct SizedStream<S: Unpin> { /* fields omitted */ }
Type represent streaming body. This body implementation should be used if total size of stream is known. Data get sent as is without using transfer encoding.
Implementations