Struct actix_http::client::TcpConnect[][src]

pub struct TcpConnect<T> { /* fields omitted */ }

Connection info.

Implementations

impl<T> Connect<T> where
    T: Address
[src]

pub fn new(req: T) -> Connect<T>[src]

Create Connect instance by splitting the string by ‘:’ and convert the second part to u16

pub fn with_addr(req: T, addr: SocketAddr) -> Connect<T>[src]

Create new Connect instance from host and address. Connector skips name resolution stage for such connect messages.

pub fn set_port(self, port: u16) -> Connect<T>[src]

Use port if address does not provide one.

Default value is 0.

pub fn set_addr(self, addr: Option<SocketAddr>) -> Connect<T>[src]

Set address.

pub fn set_addrs<I>(self, addrs: I) -> Connect<T> where
    I: IntoIterator<Item = SocketAddr>, 
[src]

Set list of addresses.

pub fn set_local_addr(self, addr: impl Into<IpAddr>) -> Connect<T>[src]

Set local_addr of connect.

pub fn hostname(&self) -> &str[src]

Get hostname.

pub fn port(&self) -> u16[src]

Get request port.

pub fn addrs(&self) -> ConnectAddrsIter<'_>[src]

Get resolved request addresses.

pub fn take_addrs(&mut self) -> ConnectAddrsIter<'static>[src]

Take resolved request addresses.