pub struct TcpConnection<T, U> { /* fields omitted */ }
Reconstruct from a parts.
Deconstruct into a parts.
Replace inclosed object, return new Stream and old object
Returns a shared reference to the underlying stream.
Returns a mutable reference to the underlying stream.
Formats the value using the given formatter. Read more
The resulting type after dereferencing.
Mutably dereferences the value.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,