pub struct Encoder<B> { /* private fields */ }
The type of error that will be returned if streaming body fails. Read more
Attempt to pull out the next chunk of body bytes. Read more
Try to convert into the complete chunk of body bytes. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.