Enum actix_http::error::ParseError [−][src]
#[non_exhaustive]
pub enum ParseError {
Method,
Uri(InvalidUri),
Version,
Header,
TooLarge,
Incomplete,
Status,
Timeout,
Io(Error),
Utf8(Utf8Error),
}A set of errors that can occur during parsing HTTP streams.
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
An invalid Method, such as GE.T.
Uri(InvalidUri)An invalid Uri, such as exam ple.domain.
An invalid HttpVersion, such as HTP/1.1
An invalid Header.
A message head is too large to be reasonable.
A message reached EOF, but is not complete.
An invalid Status, such as 1337 ELITE.
A timeout occurred waiting for an IO event.
Io(Error)An io::Error that occurred while trying to read or write to a network stream.
Utf8(Utf8Error)Parsing a field as string failed