Function actix_http::error::ErrorBadGateway [−][src]
pub fn ErrorBadGateway<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a BAD_GATEWAY response.
pub fn ErrorBadGateway<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a BAD_GATEWAY response.