Function actix_http::error::ErrorBadRequest [−][src]
pub fn ErrorBadRequest<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a BAD_REQUEST response.
pub fn ErrorBadRequest<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a BAD_REQUEST response.