Function actix_http::error::ErrorConflict [−][src]
pub fn ErrorConflict<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a CONFLICT response.
pub fn ErrorConflict<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a CONFLICT response.