Function actix_http::error::ErrorImATeapot [−][src]
pub fn ErrorImATeapot<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a IM_A_TEAPOT response.
pub fn ErrorImATeapot<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a IM_A_TEAPOT response.