Function actix_http::error::ErrorNotExtended [−][src]
pub fn ErrorNotExtended<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a NOT_EXTENDED response.
pub fn ErrorNotExtended<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a NOT_EXTENDED response.