Function actix_http::error::ErrorNotFound [−][src]
pub fn ErrorNotFound<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a NOT_FOUND response.
pub fn ErrorNotFound<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a NOT_FOUND response.