Function actix_http::error::ErrorUriTooLong [−][src]
pub fn ErrorUriTooLong<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a URI_TOO_LONG response.
pub fn ErrorUriTooLong<T>(err: T) -> Error where
T: Debug + Display + 'static,
Helper function that wraps any error and generates a URI_TOO_LONG response.