pub enum IfMatch {
Any,
Items(Vec<EntityTag>),
}Expand description
If-Match header, defined in
RFC7232
The If-Match header field makes the request method conditional on
the recipient origin server either having at least one current
representation of the target resource, when the field-value is “*”,
or having a current representation of the target resource that has an
entity-tag matching a member of the list of entity-tags provided in
the field-value.
An origin server MUST use the strong comparison function when
comparing entity-tags for If-Match, since the client
intends this precondition to prevent the method from being applied if
there have been any changes to the representation data.
ABNF
If-Match = "*" / 1#entity-tagExample values
"xyzzy"- “xyzzy”, “r2d2xxxx”, “c3piozzzz”
Examples
use actix_http::Response;
use actix_http::http::header::IfMatch;
let mut builder = Response::Ok();
builder.set(IfMatch::Any);use actix_http::Response;
use actix_http::http::header::{IfMatch, EntityTag};
let mut builder = Response::Ok();
builder.set(
IfMatch::Items(vec![
EntityTag::new(false, "xyzzy".to_owned()),
EntityTag::new(false, "foobar".to_owned()),
EntityTag::new(false, "bazquux".to_owned()),
])
);Variants
Any
Any value is a match
Items(Vec<EntityTag>)
Only the listed items are a match