Struct actix_http::http::header::Allow [−][src]
Allow header, defined in RFC7231
The Allow header field lists the set of methods advertised as
supported by the target resource. The purpose of this field is
strictly to inform the recipient of valid request methods associated
with the resource.
ABNF
Allow = #method
Example values
GET, HEAD, PUTOPTIONS, GET, PUT, POST, DELETE, HEAD, TRACE, CONNECT, PATCH, fOObAr- ``
Examples
use actix_http::Response; use actix_http::http::header::Allow; use http::Method; let mut builder = Response::Ok(); builder.set( Allow(vec![Method::GET]) );
use actix_http::Response; use actix_http::http::header::Allow; use http::Method; let mut builder = Response::Ok(); builder.set( Allow(vec![ Method::GET, Method::POST, Method::PATCH, ]) );
Tuple Fields
0: Vec<Method>Trait Implementations
Returns the name of the header field
Parse a header
type Error = InvalidHeaderValue
type Error = InvalidHeaderValue
The type returned in the event of a conversion error.
Try to convert value to a Header value.