Struct actix_http::http::header::ExtendedValue
source · [−]pub struct ExtendedValue {
pub charset: Charset,
pub language_tag: Option<LanguageTag>,
pub value: Vec<u8>,
}Expand description
The value part of an extended parameter consisting of three parts:
the REQUIRED character set name (charset), the OPTIONAL language information (language_tag),
and a character sequence representing the actual value (value), separated by single quote
characters. It is defined in RFC 5987.
Fields
charset: CharsetThe character set that is used to encode the value to a string.
language_tag: Option<LanguageTag>The human language details of the value, if available.
value: Vec<u8>The parameter value, as expressed in octets.