[−][src]Struct actix_http::Extensions
A type map of request extensions.
Implementations
impl Extensions[src]
pub fn new() -> Extensions[src]
Create an empty Extensions.
pub fn insert<T: 'static>(&mut self, val: T)[src]
Insert a type into this Extensions.
If a extension of this type already existed, it will be returned.
pub fn contains<T: 'static>(&self) -> bool[src]
Check if container contains entry
pub fn get<T: 'static>(&self) -> Option<&T>[src]
Get a reference to a type previously inserted on this Extensions.
pub fn get_mut<T: 'static>(&mut self) -> Option<&mut T>[src]
Get a mutable reference to a type previously inserted on this Extensions.
pub fn remove<T: 'static>(&mut self) -> Option<T>[src]
Remove a type from this Extensions.
If a extension of this type existed, it will be returned.
pub fn clear(&mut self)[src]
Clear the Extensions of all inserted extensions.
pub fn extend(&mut self, other: Extensions)[src]
Extends self with the items from another Extensions.