pub struct Codec { /* fields omitted */ }Expand description
WebSockets protocol codec
Create new websocket frames decoder
Set max frame size
By default max size is set to 64kb
Set decoder to client mode.
By default decoder works in server mode.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
The type of decoded frames.
The type of unrecoverable frame decoding errors. Read more
Attempts to decode a frame from the provided buffer of bytes. Read more
A default method available to be called when there are no more bytes
available to be read from the underlying I/O. Read more
Provides a Stream and Sink interface for reading and writing to this
Io object, using Decode and Encode to read and write the raw data. Read more
Encodes a frame into the buffer provided. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,