Module actix_http::client[][src]

HTTP client.

Structs

Connect
Connector

Manages HTTP client network connectivity.

TcpConnect

Connection info.

TcpConnection

Enums

ConnectError

A set of errors that can occur while connecting to an HTTP host

FreezeRequestError

A set of errors that can occur during freezing a request

InvalidUrl
Protocol

Protocol version

SendRequestError

A set of errors that can occur during request sending and response reading

TcpConnectError

Traits

Connection