[][src]Module actix_http::client

Http client api

Structs

Connector

Http client connector builde instance. Connector type uses builder-like pattern for connector service construction.

Enums

ConnectError

A set of errors that can occur while connecting to an HTTP host

InvalidUrl
SendRequestError

A set of errors that can occur during request sending and response reading

Traits

Connection