Enum actix_http::client::FreezeRequestError [−][src]
#[non_exhaustive]
pub enum FreezeRequestError {
Url(InvalidUrl),
Http(HttpError),
Custom(Box<dyn StdError>, Box<dyn Debug>),
}Expand description
A set of errors that can occur during freezing a request
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Url(InvalidUrl)Invalid URL
Http(HttpError)HTTP error
Other errors that can occur after submitting a request.