Enum actix_http::client::SendRequestError [−][src]
#[non_exhaustive]
pub enum SendRequestError {
Url(InvalidUrl),
Connect(ConnectError),
Send(Error),
Response(ParseError),
Http(HttpError),
H2(Error),
Timeout,
TunnelNotSupported,
Body(Error),
Custom(Box<dyn StdError>, Box<dyn Debug>),
}Expand description
A set of errors that can occur during request sending and response reading
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Url(InvalidUrl)Invalid URL
Tuple Fields of Url
0: InvalidUrlConnect(ConnectError)Failed to connect to host
Tuple Fields of Connect
0: ConnectErrorSend(Error)Error sending request
Tuple Fields of Send
0: ErrorResponse(ParseError)Error parsing response
Tuple Fields of Response
0: ParseErrorHttp(HttpError)Http error
Tuple Fields of Http
0: HttpErrorH2(Error)Http2 error
Tuple Fields of H2
0: ErrorResponse took too long
Tunnels are not supported for HTTP/2 connection
Body(Error)Error sending request body
Tuple Fields of Body
0: ErrorOther errors that can occur after submitting a request.