pub struct TcpConnect<T> { /* fields omitted */ }Expand description
Create Connect instance by splitting the string by ‘:’ and convert the second part to u16
Create new Connect instance from host and address. Connector skips name resolution stage
for such connect messages.
Use port if address does not provide one.
Default value is 0.
Set local_addr of connect.
Get resolved request addresses.
Take resolved request addresses.
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Compare self to key and return true if they are equal.
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,