Module actix_http::error [−][src]
Error and Result module
Structs
| BlockingError | A set of errors that can occur running blocking tasks in thread pool. |
| Error | General purpose actix web error. |
| InternalError | Helper type that can wrap any error and generate custom response. |
Enums
| ContentTypeError | A set of error that can occur during parsing content type. |
| DispatchError | A set of errors that can occur during dispatching HTTP requests. |
| ParseError | A set of errors that can occur during parsing HTTP streams. |
| PayloadError | A set of errors that can occur during payload parsing. |
Traits
| ResponseError | Error that can be converted to |
Functions
| ErrorBadGateway | Helper function that wraps any error and generates a |
| ErrorBadRequest | Helper function that wraps any error and generates a |
| ErrorConflict | Helper function that wraps any error and generates a |
| ErrorExpectationFailed | Helper function that wraps any error and generates a |
| ErrorFailedDependency | Helper function that wraps any error and generates a |
| ErrorForbidden | Helper function that wraps any error and generates a |
| ErrorGatewayTimeout | Helper function that wraps any error and generates a |
| ErrorGone | Helper function that wraps any error and generates a |
| ErrorHttpVersionNotSupported | Helper function that wraps any error and generates a |
| ErrorImATeapot | Helper function that wraps any error and generates a |
| ErrorInsufficientStorage | Helper function that wraps any error and generates a |
| ErrorInternalServerError | Helper function that wraps any error and generates a |
| ErrorLengthRequired | Helper function that wraps any error and generates a |
| ErrorLocked | Helper function that wraps any error and generates a |
| ErrorLoopDetected | Helper function that wraps any error and generates a |
| ErrorMethodNotAllowed | Helper function that wraps any error and generates a |
| ErrorMisdirectedRequest | Helper function that wraps any error and generates a |
| ErrorNetworkAuthenticationRequired | Helper function that wraps any error and generates a |
| ErrorNotAcceptable | Helper function that wraps any error and generates a |
| ErrorNotExtended | Helper function that wraps any error and generates a |
| ErrorNotFound | Helper function that wraps any error and generates a |
| ErrorNotImplemented | Helper function that wraps any error and generates a |
| ErrorPayloadTooLarge | Helper function that wraps any error and generates a |
| ErrorPaymentRequired | Helper function that wraps any error and generates a |
| ErrorPreconditionFailed | Helper function that wraps any error and generates a |
| ErrorPreconditionRequired | Helper function that wraps any error and generates a |
| ErrorProxyAuthenticationRequired | Helper function that wraps any error and generates a |
| ErrorRangeNotSatisfiable | Helper function that wraps any error and generates a |
| ErrorRequestHeaderFieldsTooLarge | Helper function that wraps any error and generates a |
| ErrorRequestTimeout | Helper function that wraps any error and generates a |
| ErrorServiceUnavailable | Helper function that wraps any error and generates a |
| ErrorTooManyRequests | Helper function that wraps any error and generates a |
| ErrorUnauthorized | Helper function that wraps any error and generates a |
| ErrorUnavailableForLegalReasons | Helper function that wraps any error and generates a |
| ErrorUnprocessableEntity | Helper function that wraps any error and generates a |
| ErrorUnsupportedMediaType | Helper function that wraps any error and generates a |
| ErrorUpgradeRequired | Helper function that wraps any error and generates a |
| ErrorUriTooLong | Helper function that wraps any error and generates a |
| ErrorVariantAlsoNegotiates | Helper function that wraps any error and generates a |
Type Definitions
| Result | A specialized |