Enum actix_http::error::DispatchError [−][src]
#[non_exhaustive]
pub enum DispatchError {
Service(Response<AnyBody>),
Body(Box<dyn StdError>),
Upgrade,
Io(Error),
Parse(ParseError),
H2(Error),
SlowRequestTimeout,
DisconnectTimeout,
PayloadIsNotConsumed,
MalformedRequest,
InternalError,
Unknown,
}Expand description
A set of errors that can occur during dispatching HTTP requests.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Service error
Body error
Upgrade service error
An io::Error that occurred while trying to read or write to a network stream.
Tuple Fields of Io
0: ErrorHttp request parse error.
Tuple Fields of Parse
0: ParseErrorHttp/2 error
Tuple Fields of H2
0: ErrorThe first request did not complete within the specified timeout.
Disconnect timeout. Makes sense for ssl streams.
Payload is not consumed
Malformed request
Internal error
Unknown error