Enum actix_http::error::ParseError [−][src]
pub enum ParseError {
Method,
Uri(InvalidUri),
Version,
Header,
TooLarge,
Incomplete,
Status,
Timeout,
Io(Error),
Utf8(Utf8Error),
}Expand description
A set of errors that can occur during parsing HTTP streams
Variants
An invalid Method, such as GE.T.
An invalid Uri, such as exam ple.domain.
Tuple Fields of Uri
0: InvalidUriAn invalid HttpVersion, such as HTP/1.1
An invalid Header.
A message head is too large to be reasonable.
A message reached EOF, but is not complete.
An invalid Status, such as 1337 ELITE.
A timeout occurred waiting for an IO event.
An io::Error that occurred while trying to read or write to a network
stream.
Tuple Fields of Io
0: ErrorParsing a field as string failed
Tuple Fields of Utf8
0: Utf8ErrorTrait Implementations
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.