pub struct Extensions { /* fields omitted */ }Expand description
A type map of request extensions.
Create an empty Extensions.
Insert a type into this Extensions.
If a extension of this type already existed, it will
be returned.
Check if container contains entry
Get a reference to a type previously inserted on this Extensions.
Get a mutable reference to a type previously inserted on this Extensions.
Remove a type from this Extensions.
If a extension of this type existed, it will be returned.
Clear the Extensions of all inserted extensions.
Extends self with the items from another Extensions.
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,