Struct actix_http::Request [−][src]
Request
Implementations
impl Request<PayloadStream>[src]
pub fn new() -> Request<PayloadStream>[src]
Create new Request instance
impl<P> Request<P>[src]
pub fn with_payload(payload: Payload<P>) -> Request<P>[src]
Create new Request instance
pub fn replace_payload<P1>(
self,
payload: Payload<P1>
) -> (Request<P1>, Payload<P>)[src]
self,
payload: Payload<P1>
) -> (Request<P1>, Payload<P>)
Create new Request instance
pub fn payload(&mut self) -> &mut Payload<P>[src]
Get request’s payload
pub fn take_payload(&mut self) -> Payload<P>[src]
Get request’s payload
pub fn into_parts(self) -> (Message<RequestHead>, Payload<P>)[src]
Split request into request head and payload
pub fn head(&self) -> &RequestHead[src]
Http message part of the request
pub fn headers_mut(&mut self) -> &mut HeaderMap[src]
Mutable reference to the message’s headers.
pub fn uri(&self) -> &Uri[src]
Request’s uri.
pub fn uri_mut(&mut self) -> &mut Uri[src]
Mutable reference to the request’s uri.
pub fn method(&self) -> &Method[src]
Read the Request method.
pub fn version(&self) -> Version[src]
Read the Request Version.
pub fn path(&self) -> &str[src]
The target path of this Request.
pub fn upgrade(&self) -> bool[src]
Check if request requires connection upgrade
pub fn peer_addr(&self) -> Option<SocketAddr>[src]
Peer socket address.
Peer address is the directly connected peer’s socket address. If a proxy is used in front of the Actix Web server, then it would be address of this proxy.
Will only return None when called in unit tests.