Module actix_http::ws [−][src]
WebSocket protocol support.
To setup a WebSocket, first do web socket handshake then on success
convert Payload into a WsStream stream and then use WsWriter to
communicate with the peer.
Structs
Reason for closing the connection
WebSockets protocol codec
A struct representing a WebSocket frame.
Enums
Status code used to indicate why an endpoint is closing the WebSocket
connection.
WebSocket frame
Websocket handshake errors
WebSocket continuation item
WebSocket Message
Operation codes as part of rfc6455.
Websocket protocol errors
Functions
Verify WebSocket handshake request and create handshake response.
Create websocket handshake response
Verify WebSocket handshake request.